@@ -15,22 +15,22 @@ use URI;
 
 =head1 NAME
 
-Geo::Coder::CA - Provides a geocoding functionality using http:://geocoder.ca for both Canada and the US.
+Geo::Coder::CA - Provides a Geo-Coding functionality using http:://geocoder.ca for both Canada and the US.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 SYNOPSIS
 
       use Geo::Coder::CA;
 
-      my $geocoder = Geo::Coder::CA->new();
-      my $location = $geocoder->geocode(location => '9235 Main St, Richibucto, New Brunswick, Canada');
+      my $geo_coder = Geo::Coder::CA->new();
+      my $location = $geo_coder->geocode(location => '9235 Main St, Richibucto, New Brunswick, Canada');
 
 =head1 DESCRIPTION
 
@@ -40,10 +40,10 @@ Geo::Coder::CA provides an interface to geocoder.ca.  Geo::Coder::Canada no long
 
 =head2 new
 
-    $geocoder = Geo::Coder::CA->new();
+    $geo_coder = Geo::Coder::CA->new();
     my $ua = LWP::UserAgent->new();
     $ua->env_proxy(1);
-    $geocoder = Geo::Coder::CA->new(ua => $ua);
+    $geo_coder = Geo::Coder::CA->new(ua => $ua);
 
 =cut
 
@@ -58,8 +58,8 @@ sub new {
 
 =head2 geocode
 
-    $location = $geocoder->geocode(location => $location);
-    # @location = $geocoder->geocode(location => $location);
+    $location = $geo_coder->geocode(location => $location);
+    # @location = $geo_coder->geocode(location => $location);
 
     print 'Latitude: ', $location->{'latt'}, "\n";
     print 'Longitude: ', $location->{'longt'}, "\n";
@@ -111,9 +111,9 @@ sub geocode {
 			# $query_parameters{'locate'} = "$1 County, $2, $3";
 			# $uri->query_form(%query_parameters);
 			# $url = $uri->as_string();
-			# 
+			#
 			# $res = $self->{ua}->get($url);
-			# 
+			#
 			# if($res->is_error()) {
 				# Carp::croak("geocoder.ca API returned error: " . $res->status_line());
 				# return;
@@ -132,13 +132,13 @@ Accessor method to get and set UserAgent object used internally. You
 can call I<env_proxy> for example, to get the proxy information from
 environment variables:
 
-  $geocoder->ua()->env_proxy(1);
+    $geo_coder->ua()->env_proxy(1);
 
 You can also set your own User-Agent object:
 
-  my $ua = LWP::UserAgent::Throttled->new();
-  $ua->throttle('geocoder.ca' => 1);
-  $geocoder->ua($ua);
+    my $ua = LWP::UserAgent::Throttled->new();
+    $ua->throttle('geocoder.ca' => 1);
+    $geo_coder->ua($ua);
 
 =cut
 
@@ -152,7 +152,7 @@ sub ua {
 
 =head2 reverse_geocode
 
-    $location = $geocoder->reverse_geocode(latlng => '37.778907,-122.39732');
+    $location = $geo_coder->reverse_geocode(latlng => '37.778907,-122.39732');
 
 Similar to geocode except it expects a latitude/longitude parameter.
 
@@ -193,7 +193,7 @@ sub run {
 
 	my @rc = $class->new()->geocode($location);
 
-	die "$0: geocoding failed" unless(scalar(@rc));
+	die "$0: geo-coding failed" unless(scalar(@rc));
 
 	print Data::Dumper->new([\@rc])->Dump();
 }
@@ -219,7 +219,7 @@ L<Geo::Coder::GooglePlaces>, L<HTML::GoogleMaps::V3>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017 Nigel Horne.
+Copyright 2017-2018 Nigel Horne.
 
 This program is released under the following licence: GPL2
 
